@@ -21,7 +21,7 @@ sub new {
 sub build_requires {
     my ( $self, @extra ) = @_;
     return +{
-	'Test::More'	=> 0.88,	# Because of done_testing().
+	'Test::More'	=> 0.96,	# Because of subtest().
 	@extra,
     };
 }
@@ -171,7 +171,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2013 by Thomas R. Wyant, III
+Copyright (C) 2010-2014 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
